@@ -545,8 +545,6 @@ function applySkin() {
 		themeReady();
 	}
 
-	tuneFilter();
-
 	makeFiltersResponsive();
 
 	setupResponsiveMenuAndTabs();
@@ -788,12 +786,6 @@ function responsiveUI(event) {
 		tree = false;
 	}
 
-	if ($('#navigation').length) {
-		mainWidth = $('body').innerWidth() - $('#navigation').width();
-	} else {
-		mainWidth = $('body').innerWidth();
-	}
-
 	if ($(window).width() < 640) {
 		menuHide(tree);
 		menuHideResponsive = true;
@@ -810,6 +802,12 @@ function responsiveUI(event) {
 		menuShow(tree);
 	}
 
+	if ($('#navigation').length && $('#navigation').is(':visible')) {
+		mainWidth = $('body').innerWidth() - $('#navigation').width();
+	} else {
+		mainWidth = $('body').innerWidth();
+	}
+
 	/* change textbox and textarea widths */
 	$('input[type="text"], textarea').each(function() {
 		if ($(this).attr('type') == 'text') {
@@ -844,6 +842,75 @@ function responsiveUI(event) {
 	});
 }
 
+function responsiveResizeGraphs() {
+	if ($('.graphimage').length == 0) {
+		return false;
+	}
+
+	if ($('#navigation').length && $('#navigation').is(':visible')) {
+		mainWidth = $('body').innerWidth() - $('#navigation').width();
+	} else {
+		mainWidth = $('body').innerWidth();
+	}
+
+	myColumns = $('#columns').val();
+	isThumb   = $('#thumbnails').is(':checked');
+	graphRow  = $('.tableRowGraph:first').width();
+	drillDown = $('.graphDrillDown:first').outerWidth() + 15;
+
+	if (myColumns == null) {
+		myColumns = 1;
+	}
+
+	if (mainWidth < graphRow) {
+		graphRow = mainWidth - drillDown;
+	} else if (graphRow == 0) {
+		graphRow = mainWidth;
+	}
+
+	myWidth = parseInt((graphRow - (drillDown * myColumns)) / myColumns);
+
+	$('.graphimage').each(function() {
+		graph_id = $(this).attr('id').replace('wrapper_','');
+
+		/* original image attributes */
+		image_width   = $(this).attr('image_width');
+		image_height  = $(this).attr('image_height');
+		canvas_top    = $(this).attr('canvas_top');
+		canvas_left   = $(this).attr('canvas_left');
+		canvas_width  = $(this).attr('canvas_width');
+		canvas_height = $(this).attr('canvas_height');
+
+		if (isThumb || myWidth < image_width) {
+			ratio = myWidth / image_width;
+		} else {
+			ratio = 1;
+		}
+
+		new_image_width       = parseInt(image_width * ratio)
+		new_image_height      = parseInt(image_height * ratio)
+		new_canvas_width      = parseInt(canvas_width  * ratio);
+		new_canvas_height     = parseInt(canvas_height * ratio);
+		new_canvas_graph_top  = parseInt(canvas_top  * ratio);
+		new_canvas_graph_left = parseInt(canvas_left * ratio);
+
+		$(this).attr('graph_width', new_canvas_width);
+		$(this).attr('graph_height', new_canvas_height);
+		$(this).attr('graph_top', new_canvas_graph_top);
+		$(this).attr('graph_left', new_canvas_graph_left);
+
+		$(this).css('width', new_image_width);
+		$(this).css('height', new_image_height);
+
+		$('#zoom-container').remove();
+		$(this).zoom({
+			inputfieldStartTime : 'date1',
+			inputfieldEndTime : 'date2',
+			serverTimeOffset : timeOffset
+		});
+	});
+}
+
 function countHiddenCols(object) {
 	hidden = 0;
 	$(object).find('th').each(function() {
@@ -921,19 +988,32 @@ function tuneTable(object, width) {
 }
 
 function tuneFilter(object, width) {
-	filter = 'input[id="refresh"], input[id="clear"], input[id="save"], input[id="tsrefresh"], input[id="tsclear"]';
-	buttons = $(object).find(filter).length;
+	filter  = 'input[id="refresh"], input[id="clear"], input[id="save"], input[id="tsrefresh"], input[id="tsclear"]';
+	buttons = 0;
+	visTds  = $(object).find('td:visible').length;
+
+	// Find the td's with buttons
+	$($(object).find('td').get().reverse()).each(function() {
+		if ($(this).find(filter).length > 0) {
+			buttons++;
+		}
+	});
+	minTds  = 2 + buttons;
 
 	if ($(object).width() > width) {
 		$($(object).find('td').get().reverse()).each(function() {
-			if (!$(this).find(filter).length) {
-				// always show two objects
-				if ($(object).find('td:visible').length - buttons > 2) {
-					$(this).hide();
+			if (visTds < minTds) {
+				return false;
+			}
 
-					if ($(this).closest('td').prev().find('input, select').length == 0) {
-						$(this).closest('td').prev().hide();
-					}
+			if ($(this).find(filter).length == 0) {
+				// always show two objects
+				$(this).hide();
+				visTds--;
+
+				if ($(this).closest('td').prev().find('input, select').length == 0) {
+					$(this).closest('td').prev().hide();
+					visTds--;
 				}
 			}
 
@@ -962,35 +1042,48 @@ function tuneFilter(object, width) {
 	}
 }
 
-function menuHide(tree) {
-	curMargin = $('#navigation_right').css('margin-left');
+function menuHide() {
+	myClass = '';
+    curMargin = $('#navigation').outerWidth();
 	if (curMargin > 0) {
 		marginLeft = curMargin;
 	}
 
-	if (tree) {
+	if ($('.cactiTreeNavigationArea').length) {
 		myClass = '.cactiTreeNavigationArea';
-	}else{
+	} else if ($('.cactiConsoleNavigationArea').length) {
 		myClass = '.cactiConsoleNavigationArea';
 	}
 
 	$('#navigation_right').animate({'margin-left': '0px'}, 20);
-	$(myClass).hide('slide', {direction: 'left'}, 20);
+
+	if (myClass != '') {
+		$(myClass).hide('slide', {direction: 'left'}, 20, function() {
+			responsiveResizeGraphs();
+		});
+	}
 
 	menuOpen = false;
 }
 
 function menuShow(tree) {
-	if (tree) {
+	myClass = '';
+
+	if ($('.cactiTreeNavigationArea').length) {
 		myClass = '.cactiTreeNavigationArea';
-	}else{
+	} else if ($('.cactiConsoleNavigationArea').length) {
 		myClass = '.cactiConsoleNavigationArea';
 	}
 
-	if (marginLeft != null) {
+	if (marginLeft > 0) {
 		$('#navigation_right').animate({'margin-left': marginLeft}, 20);
 	}
-	$(myClass).show('slide', {direction: 'left'}, 20);
+
+	if (myClass != '') {
+		$(myClass).show('slide', {direction: 'left'}, 20, function() {
+			responsiveResizeGraphs();
+		});
+	}
 
 	menuOpen = true;
 }
@@ -1495,6 +1588,8 @@ function keepWindowSize() {
 
 		navWidth = $('#navigation').width();
 		$('#searcher').css('width', navWidth-70);
+
+		responsiveResizeGraphs();
 	}).resize();
 }
 
@@ -1781,15 +1876,22 @@ function dryRunRangeFill(local_graph_id) {
 
 function redrawGraph(graph_id) {
 	mainWidth = $('#main').width();
-	myColumns = $('#columns').val();
 	isThumb   = $('#thumbnails').is(':checked');
 
-	if (isThumb) {
-		myWidth = (mainWidth-(30*myColumns))/myColumns;
+	myColumns = $('#columns').val();
+	graphRow  = $('.tableRowGraph').width();
+	drillDown = $('.graphDrillDown:first').outerWidth() + 10;
+
+	if (mainWidth < graphRow) {
+		graphRow = mainWidth - drillDown;
+	} else if (graphRow == 0) {
+		graphRow = mainWidth;
 	}
 
-	graph_height=$('#wrapper_'+graph_id).attr('graph_height');
-	graph_width=$('#wrapper_'+graph_id).attr('graph_width');
+	myWidth = (graphRow-(drillDown * myColumns)) / myColumns;
+
+	graph_height= $('#wrapper_'+graph_id).attr('graph_height');
+	graph_width = $('#wrapper_'+graph_id).attr('graph_width');
 
 	$.getJSON(urlPath+'graph_json.php?rra_id=0'+
 		'&local_graph_id='+graph_id+
@@ -1799,17 +1901,36 @@ function redrawGraph(graph_id) {
 		'&graph_width='+graph_width+
 		(isThumb ? '&graph_nolegend=true':''),
 		function(data) {
-			if (isThumb && myWidth < data.image_width) {
+			if (myWidth < data.image_width) {
 				ratio=myWidth/data.image_width;
-				data.image_width  *= ratio;
-				data.image_height *= ratio;
-				data.graph_width  *= ratio;
-				data.graph_height *= ratio;
-				data.graph_top    *= ratio;
-				data.graph_left   *= ratio;
+				data.image_width  = parseInt(data.image_width  * ratio);
+				data.image_height = parseInt(data.image_height * ratio);
+				data.graph_width  = parseInt(data.graph_width  * ratio);
+				data.graph_height = parseInt(data.graph_height * ratio);
+				data.graph_top    = parseInt(data.graph_top  * ratio);
+				data.graph_left   = parseInt(data.graph_left * ratio);
 			}
 
-			$('#wrapper_'+data.local_graph_id).html("<img class='graphimage' id='graph_"+data.local_graph_id+"' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
+			$('#wrapper_'+data.local_graph_id).html(
+				"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
+				" src='data:image/"+data.type+";base64,"+data.image+"'"+
+				" graph_start='"+data.graph_start+"'"+
+				" graph_end='"+data.graph_end+"'"+
+				" graph_left='"+data.graph_left+"'"+
+				" graph_top='"+data.graph_top+"'"+
+				" graph_width='"+data.graph_width+"'"+
+				" graph_height='"+data.graph_height+"'"+
+				" width='"+data.image_width+"'"+
+				" height='"+data.image_height+"'"+
+				" image_width='"+data.image_width+"'"+
+				" image_height='"+data.image_height+"'"+
+				" canvas_top='"+data.graph_top+"'"+
+				" canvas_left='"+data.graph_left+"'"+
+				" canvas_width='"+data.graph_width+"'"+
+				" canvas_height='"+data.graph_height+"'"+
+				" value_min='"+data.value_min+"'"+
+				" value_max='"+data.value_max+"'>"
+			);
 		}
 	);
 }
@@ -1869,20 +1990,41 @@ function initializeGraphs() {
 			function(data) {
 				if (myWidth < data.image_width) {
 					ratio=myWidth/data.image_width;
-					data.image_width  *= ratio;
-					data.image_height *= ratio;
-					data.graph_width  *= ratio;
-					data.graph_height *= ratio;
-					data.graph_top    *= ratio;
-					data.graph_left   *= ratio;
+					data.image_width  = parseInt(data.image_width  * ratio);
+					data.image_height = parseInt(data.image_height * ratio);
+					data.graph_width  = parseInt(data.graph_width  * ratio);
+					data.graph_height = parseInt(data.graph_height * ratio);
+					data.graph_top    = parseInt(data.graph_top  * ratio);
+					data.graph_left   = parseInt(data.graph_left * ratio);
 				}
 
-				$('#wrapper_'+data.local_graph_id).html("<img class='graphimage' id='graph_"+data.local_graph_id+"' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
+				$('#wrapper_'+data.local_graph_id).html(
+					"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
+					" src='data:image/"+data.type+";base64,"+data.image+"'"+
+					" graph_start='"+data.graph_start+"'"+
+					" graph_end='"+data.graph_end+"'"+
+					" graph_left='"+data.graph_left+"'"+
+					" graph_top='"+data.graph_top+"'"+
+					" graph_width='"+data.graph_width+"'"+
+					" graph_height='"+data.graph_height+"'"+
+					" width='"+data.image_width+"'"+
+					" height='"+data.image_height+"'"+
+					" image_width='"+data.image_width+"'"+
+					" image_height='"+data.image_height+"'"+
+					" canvas_top='"+data.graph_top+"'"+
+					" canvas_left='"+data.graph_left+"'"+
+					" canvas_width='"+data.graph_width+"'"+
+					" canvas_height='"+data.graph_height+"'"+
+					" value_min='"+data.value_min+"'"+
+					" value_max='"+data.value_max+"'>"
+				);
+
 				$("#graph_"+data.local_graph_id).zoom({
 					inputfieldStartTime : 'date1',
 					inputfieldEndTime : 'date2',
 					serverTimeOffset : timeOffset
 				});
+
 				realtimeArray[data.local_graph_id] = false;
 		});
 	});
@@ -1918,7 +2060,11 @@ function initializeGraphs() {
 		if (realtimeArray[graph_id]) {
 			$('#wrapper_'+graph_id).html(keepRealtime[graph_id]).change();
 			$(this).html("<img class='drillDown' title='"+realtimeClickOn+"' alt='' src='"+urlPath+"images/chart_curve_go.png'>");
-			$(this).find('img').tooltip().zoom({ inputfieldStartTime : 'date1', inputfieldEndTime : 'date2', serverTimeOffset : timeOffset });
+			$(this).find('img').tooltip().zoom({ 
+				inputfieldStartTime : 'date1', 
+				inputfieldEndTime : 'date2', 
+				serverTimeOffset : timeOffset 
+			});
 			realtimeArray[graph_id] = false;
 			setFilters();
 		}else{
